settings = {
    'contributions': {
        'type_code': 'RCPT',
        'full_pull': {
            'indexes': range(36),
            'header': [
                'Record Type',
                'Name of Schedule',
                'Unique ID',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Out-of-state PAC Check-box',
                'Out-of-state PAC FEC ID',
                'Date',
                'Amount/In-kind Value',
                'Description',
                'Employer',
                'Principal Occupation/Job Title',
                'Job Title',
                'Spouse Law firm of spouse',
                'Child Parent Law Firm 1',
                'Child Parent Law Firm 2',
                'Travel Outside Texas (If In-kind)',
                'Traveler Last Name (If in-kind)',
                'Traveler First Name(s)',
                'Traveler Title',
                'Traveler Suffix',
                'Means of Transport',
                'Name of Each Departure City/Location',
                'Departure Date',
                'Name of Each Destination City/Location',
                'Arrival Date in Destination City/Location',
                'Purpose of Travel',
                'Item_ID of Parent Record',
            ]
        },
        'basic_pull': {
            'indexes': [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 15, 16, 17, 18, 19, 24],
            'header': [
                'Unique ID',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Date',
                'Amount/In-kind Value',
                'Description',
                'Employer',
                'Principal Occupation/Job Title',
                'Travel Outside Texas (If In-kind)',
            ]
        }
    },
    'expenditures': {
    'type_code': 'EXPN',
        'full_pull': {
            'indexes': range(42),
            'header': [
                'Record Type',
                'Name of Schedule',
                'Unique ID ',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Date',
                'Amount',
                'Description',
                'Expenditure is Contribution',
                'Reimbursement Intended ',
                'Candidate Last Name',
                'Candidate First Name(s)',
                'Candidate Title',
                'Candidate Suffix',
                'Office Held Code',
                'Office Held Description',
                'Office Held District',
                'Office Sought Code',
                'Office Sought Description',
                'Office Sought District',
                'Item_ID of Parent Record',
                'Expend from Corporate/Labor Contribution',
                'Travel Outside Texas',
                'Traveler Last Name',
                'Traveler First Name(s)',
                'Traveler Title',
                'Traveler Suffix',
                'Means of Transport',
                'Name of Each Departure City/Location',
                'Departure Date',
                'Name of Each Destination City/Location',
                'Arrival Date in Destination City/Location',
                'Purpose of Travel',
                'Item_ID of Parent Record (Travel)',
            ]
        },
        'basic_pull': {
            'indexes': [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15],
            'header': [
                'Unique ID',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Date',
                'Amount',
                'Description',
            ]
        }
    }
}
